queues

package
v0.0.0-...-97e7716 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package queues

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Queue

type Queue[T comparable] interface {
	Enqueue(value T)
	Dequeue() (value T, ok bool)
	Peek() (value T, ok bool)

	containers.Container[T]
}

Directories

Path Synopsis
Package arrayqueue provides a generic queue implementation using a dynamic array.
Package arrayqueue provides a generic queue implementation using a dynamic array.
Package circularqueue implements a circular queue based on a slice.
Package circularqueue implements a circular queue based on a slice.
Package linkedqueue provides a generic queue implementation using a singly linked list.
Package linkedqueue provides a generic queue implementation using a singly linked list.

Jump to